import { axios } from '@/utils/request'


/**
 * 会议室统计数据
 * /admin/ms/roomStats
 * @参数 day 格式：2024-09-30
 * @返回
 *      alreadyBooking, 已预约会议室数量
 *      noBooking,未预约会议室数量
 *      going,开会中会议室数量
 *      free,空闲中会议室数量
 * @param parameter
 * @returns {AxiosPromise}
 */
export function getNum(parameter) {
  return axios({
    url: '/admin/ms/roomStats',
    method: 'post',
    params: parameter
  })
}

/**
 * 按日历统计数据
 * /admin/ms/calendar
 *     @参数 month 月份，格式：2024-09
 *     @返回,月份的每一天 的 预约记录
 * @param parameter
 * @returns {AxiosPromise}
 */
export function getCalendar(parameter) {
  return axios({
    url: '/admin/ms/calendar',
    method: 'post',
    params: parameter
  })
}

/**
 * 按照会议状态统计
 * /admin/ms/meetingStats
 * 无参
 * @返回
 *      *      wait, 待开始会议数量
 *      *      going,进行中会议数量
 *      *      closed,已结束会议数量
 * @param parameter
 * @returns {AxiosPromise}
 */
export function getStatus(parameter) {
  return axios({
    url: '/admin/ms/meetingStats',
    method: 'post',
    params: parameter
  })
}

/**
 * 会议待办 （前10条）
 * /admin/ms/meetingAudit
 * 无参
 * @param parameter
 * @returns {AxiosPromise}
 */
export function getWait(parameter) {
  return axios({
    url: '/admin/ms/meetingAudit',
    method: 'post',
    params: parameter
  })
}

/**
 * 图表统计数据
 *
 *
 *  @参数 startDate 统计数据开始时间,日期格式示例：2024-08-23
 *  @参数 endDate   统计数据结束时间,日期格式示例：2024-09-23
 *  @返回
 *  roomRank，会议室使用排名
 *  serve，服务情况
 *  roomType，会议室形式统计
 *  orgMeeting，部门开会情况（取前10个部门）
 *  everyDay，开会情况--按天（取前20天）
 */
export function getChartData(parameter) {
  return axios({
    url: '/admin/ms/chartStats',
    method: 'post',
    params: parameter
  })
}